#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const commander_1 = require("commander");
const docgen_1 = __importDefault(require("./scripts/docgen"));
const dtsgen_1 = __importDefault(require("./scripts/dtsgen"));
const doc_vitepress_1 = __importDefault(require("./scripts/doc-vitepress"));
const build_material_1 = __importDefault(require("./scripts/build-material"));
const program = new commander_1.Command();
const packageContent = fs_extra_1.default.readFileSync(path_1.default.resolve(__dirname, '../package.json'), 'utf8');
const packageData = JSON.parse(packageContent);
program
    .version(packageData.version)
    .name('digit-vue-scripts')
    .usage('command [options]');
program
    .command('docgen')
    .description('generate document of component. e.g. arco-scripts-vue docgen --components menu,affix,button')
    .option('-i, --input <filename>', 'specified input file')
    .option('-c, --components <names>', 'component name(s) joined by comma(,)')
    .action(({ input, components }) => {
    components = typeof components === 'string' ? components.split(',') : [];
    (0, docgen_1.default)({ input, components });
});
// todo: 后续会更新
program
    .command('dtsgen <files>')
    .description('emit .d.ts files for vue files.')
    .option('-o, --outDir <direname>', 'Specify an output folder for all emitted files')
    .action((files, options) => {
    (0, dtsgen_1.default)(files, options);
});
program
    .command('build:material <input>')
    .description('build vue material.')
    .action((input) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, build_material_1.default)(input);
}));
// 将 demo 的文件生成 markdown 到vitepress
program
    .command('doc-vitepress')
    .description('将文档生成到 vitepress中')
    .option('-i, --input <filename>', 'demo文件')
    .option('-o, --outDir <direname>', '输出到目录')
    .action(({ input, outDir }) => {
    (0, doc_vitepress_1.default)({ input, outDir });
});
program.parse(process.argv);
//# sourceMappingURL=index.js.map