"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTemplate = exports.cleanStr = exports.trimStr = exports.unquote = exports.isBoolean = exports.toKebabCase = exports.escapeCharacter = void 0;
/**
 * 替换换行和竖线使其能在markdown中显示
 * @param str
 */
const escapeCharacter = (str) => {
    return str.replace(/\r?\n/g, '<br>').replace(/\|/g, '\\|');
};
exports.escapeCharacter = escapeCharacter;
/**
 * 转为 kebab-case
 * @param str
 */
const toKebabCase = (str) => {
    return str.replace(/[A-Z]/g, (match, offset) => {
        return `${offset > 0 ? '-' : ''}${match.toLocaleLowerCase()}`;
    });
};
exports.toKebabCase = toKebabCase;
const opt = Object.prototype.toString;
function isBoolean(obj) {
    return opt.call(obj) === '[object Boolean]';
}
exports.isBoolean = isBoolean;
/**
 * 去掉包裹字符串的引号
 * @param {str} string
 * @returns {string}
 */
function unquote(str) {
    return str && str.replace(/^['"]|['"]$/g, '');
}
exports.unquote = unquote;
/**
 * 清理字符串前后的空格，竖线和 \n
 * @param {str} string
 * @returns {string}
 */
function trimStr(str) {
    return str && str.replace(/^(\s|\||\r?\n)*|(\s|\||\r?\n)*$/g, '');
}
exports.trimStr = trimStr;
/**
 * 清理字符串中不符合预期的字符，如 \n
 * @param {str} string
 * @returns {string}
 */
function cleanStr(str) {
    return str && str.replace(/\r?\n/g, '');
}
exports.cleanStr = cleanStr;
const getTemplate = (src, lang) => {
    const matches = Array.from(src.matchAll(/##\s+(zh-CN|en-US)\n+(.+?)\n+---(?:\n|$)/gs));
    for (const item of matches) {
        if (new RegExp(lang).test(item[1])) {
            src = src.replace(item[0], `${item[2]}\n`);
        }
        else {
            src = src.replace(item[0], '');
        }
    }
    return src;
};
exports.getTemplate = getTemplate;
//# sourceMappingURL=index.js.map